@@ -17,13 +17,15 @@ License along with this program; if not, write to the
 Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301 USA
 """
-import inspect
-import time
-
 # You can put calls to p() everywhere in this page to inspect timing
+#
+# import inspect
+# import time
 # g_start = time.time()
 # def p():
 #     print(time.time() - g_start, __file__, inspect.currentframe().f_back.f_lineno)
+
+import builtins
 import logging
 import os
 import signal
@@ -31,24 +33,34 @@ import subprocess
 import sys
 import uuid
 
-from locale import gettext as _
+from locale import gettext
+
+builtins.__dict__["_"] = gettext
+
 from optparse import OptionParser
 
 log = logging.getLogger(__name__)
 
+# Force use X11 backend under wayland before any import of GDK through dependencies
+os.environ["GDK_BACKEND"] = "x11"
+
 from guake.globals import NAME
 from guake.globals import bindtextdomain
 from guake.support import print_support
 from guake.utils import restore_preferences
 from guake.utils import save_preferences
 
-# When we are in the document generation on readthedocs, we do not have paths.py generated
+# When we are in the document generation on readthedocs,
+# we do not have paths.py generated
 try:
     from guake.paths import LOCALE_DIR
+
     bindtextdomain(NAME, LOCALE_DIR)
 except:  # pylint: disable=bare-except
     pass
 
+# pylint: disable=import-outside-toplevel
+
 
 def main():
     """Parses the command line parameters and decide if dbus methods
@@ -59,262 +71,341 @@ def main():
     # Force to xterm-256 colors for compatibility with some old command line programs
     os.environ["TERM"] = "xterm-256color"
 
-    # Force use X11 backend underwayland
-    os.environ["GDK_BACKEND"] = "x11"
-
     # do not use version keywords here, pbr might be slow to find the version of Guake module
     parser = OptionParser()
     parser.add_option(
-        '-V',
-        '--version',
-        dest='version',
-        action='store_true',
+        "-V",
+        "--version",
+        dest="version",
+        action="store_true",
         default=False,
-        help=_('Show Guake version number and exit')
+        help=_("Show Guake version number and exit"),
     )
 
     parser.add_option(
-        '-v',
-        '--verbose',
-        dest='verbose',
-        action='store_true',
+        "-v",
+        "--verbose",
+        dest="verbose",
+        action="store_true",
         default=False,
-        help=_('Enable verbose logging')
+        help=_("Enable verbose logging"),
     )
 
     parser.add_option(
-        '-f',
-        '--fullscreen',
-        dest='fullscreen',
-        action='store_true',
+        "-f",
+        "--fullscreen",
+        dest="fullscreen",
+        action="store_true",
         default=False,
-        help=_('Put Guake in fullscreen mode')
+        help=_("Put Guake in fullscreen mode"),
     )
 
     parser.add_option(
-        '-t',
-        '--toggle-visibility',
-        dest='show_hide',
-        action='store_true',
+        "--unfullscreen",
+        dest="unfullscreen",
+        action="store_true",
         default=False,
-        help=_('Toggles the visibility of the terminal window')
+        help=_("Put Guake out from fullscreen mode"),
     )
 
     parser.add_option(
-        '--show',
+        "-t",
+        "--toggle-visibility",
+        dest="show_hide",
+        action="store_true",
+        default=False,
+        help=_("Toggles the visibility of the terminal window"),
+    )
+
+    parser.add_option(
+        "--show",
         dest="show",
-        action='store_true',
+        action="store_true",
         default=False,
-        help=_('Shows Guake main window')
+        help=_("Shows Guake main window"),
     )
 
     parser.add_option(
-        '--hide',
-        dest='hide',
-        action='store_true',
+        "--hide",
+        dest="hide",
+        action="store_true",
         default=False,
-        help=_('Hides Guake main window')
+        help=_("Hides Guake main window"),
     )
 
     parser.add_option(
-        '-p',
-        '--preferences',
-        dest='show_preferences',
-        action='store_true',
+        "-p",
+        "--preferences",
+        dest="show_preferences",
+        action="store_true",
         default=False,
-        help=_('Shows Guake preference window')
+        help=_("Shows Guake preference window"),
     )
 
     parser.add_option(
-        '-a',
-        '--about',
-        dest='show_about',
-        action='store_true',
+        "-a",
+        "--about",
+        dest="show_about",
+        action="store_true",
         default=False,
-        help=_('Shows Guake\'s about info')
+        help=_("Shows Guake's about info"),
     )
 
     parser.add_option(
-        '-n',
-        '--new-tab',
-        dest='new_tab',
-        action='store',
-        default='',
-        help=_('Add a new tab (with current directory set to NEW_TAB)')
+        "-n",
+        "--new-tab",
+        dest="new_tab",
+        action="store",
+        default="",
+        help=_("Add a new tab (with current directory set to NEW_TAB)"),
     )
 
     parser.add_option(
-        '-s',
-        '--select-tab',
-        dest='select_tab',
-        action='store',
-        default='',
-        help=_('Select a tab (SELECT_TAB is the index of the tab)')
+        "-s",
+        "--select-tab",
+        dest="select_tab",
+        action="store",
+        default="",
+        help=_("Select a tab (SELECT_TAB is the index of the tab)"),
     )
 
     parser.add_option(
-        '-g',
-        '--selected-tab',
-        dest='selected_tab',
-        action='store_true',
+        "-g",
+        "--selected-tab",
+        dest="selected_tab",
+        action="store_true",
         default=False,
-        help=_('Return the selected tab index.')
+        help=_("Return the selected tab index."),
     )
 
     parser.add_option(
-        '-l',
-        '--selected-tablabel',
-        dest='selected_tablabel',
-        action='store_true',
+        "-l",
+        "--selected-tablabel",
+        dest="selected_tablabel",
+        action="store_true",
         default=False,
-        help=_('Return the selected tab label.')
+        help=_("Return the selected tab label."),
     )
 
     parser.add_option(
-        '--split-vertical',
-        dest='split_vertical',
-        action='store_true',
-        default=False,
-        help=_('Split the selected tab vertically.')
-    )
-
-    parser.add_option(
-        '--split-horizontal',
-        dest='split_horizontal',
-        action='store_true',
-        default=False,
-        help=_('Split the selected tab horizontally.')
-    )
-
-    parser.add_option(
-        '-e',
-        '--execute-command',
-        dest='command',
-        action='store',
-        default='',
-        help=_('Execute an arbitrary command in the selected tab.')
-    )
-
-    parser.add_option(
-        '-i',
-        '--tab-index',
-        dest='tab_index',
-        action='store',
-        default='0',
-        help=_('Specify the tab to rename. Default is 0. Can be used to select tab by UUID.')
-    )
-
-    parser.add_option(
-        '--bgcolor',
-        dest='bgcolor',
-        action='store',
-        default='',
-        help=_('Set the hexadecimal (#rrggbb) background color of '
-               'the selected tab.')
-    )
-
-    parser.add_option(
-        '--fgcolor',
-        dest='fgcolor',
-        action='store',
-        default='',
-        help=_('Set the hexadecimal (#rrggbb) foreground color of the '
-               'selected tab.')
-    )
-
-    parser.add_option(
-        '--change-palette',
-        dest='palette_name',
-        action='store',
-        default='',
-        help=_('Change Guake palette scheme')
-    )
-
-    parser.add_option(
-        '--rename-tab',
-        dest='rename_tab',
-        metavar='TITLE',
-        action='store',
-        default='',
+        "-S",
+        "--select-terminal",
+        dest="select_terminal",
+        metavar="TERMINAL_INDEX",
+        action="store",
+        default="",
         help=_(
-            'Rename the specified tab by --tab-index. Reset to default if TITLE is '
+            "Select a specific terminal in a split tab. "
+            + "Only useful with split terminals (TERMINAL_INDEX is the index of the tab)"
+        ),
+    )
+
+    parser.add_option(
+        "--selected-terminal",
+        dest="selected_terminal",
+        action="store_true",
+        default=False,
+        help=_("Return the selected terminal index."),
+    )
+
+    parser.add_option(
+        "--split-vertical",
+        dest="split_vertical",
+        action="store_true",
+        default=False,
+        help=_("Split the selected tab vertically."),
+    )
+
+    parser.add_option(
+        "--split-horizontal",
+        dest="split_horizontal",
+        action="store_true",
+        default=False,
+        help=_("Split the selected tab horizontally."),
+    )
+
+    parser.add_option(
+        "-e",
+        "--execute-command",
+        dest="command",
+        action="store",
+        default="",
+        help=_("Execute an arbitrary command in the selected tab."),
+    )
+
+    parser.add_option(
+        "-i",
+        "--tab-index",
+        dest="tab_index",
+        action="store",
+        default="0",
+        help=_("Specify the tab to rename. Default is 0. Can be used to select tab by UUID."),
+    )
+
+    parser.add_option(
+        "--bgcolor",
+        dest="bgcolor",
+        action="store",
+        default="",
+        help=_("Set the hexadecimal (#rrggbb) background color of " "the selected tab."),
+    )
+
+    parser.add_option(
+        "--fgcolor",
+        dest="fgcolor",
+        action="store",
+        default="",
+        help=_("Set the hexadecimal (#rrggbb) foreground color of the " "selected tab."),
+    )
+
+    parser.add_option(
+        "--bgcolor-current",
+        dest="bgcolor_current",
+        action="store",
+        default="",
+        help=_("Set the hexadecimal (#rrggbb) background color of " "the current terminal."),
+    )
+
+    parser.add_option(
+        "--fgcolor-current",
+        dest="fgcolor_current",
+        action="store",
+        default="",
+        help=_("Set the hexadecimal (#rrggbb) foreground color of " "the current terminal."),
+    )
+
+    parser.add_option(
+        "--change-palette",
+        dest="palette_name",
+        action="store",
+        default="",
+        help=_("Change Guake palette scheme"),
+    )
+
+    parser.add_option(
+        "--reset-colors",
+        dest="reset_colors",
+        action="store_true",
+        default=False,
+        help=_("Set colors from settings."),
+    )
+
+    parser.add_option(
+        "--reset-colors-current",
+        dest="reset_colors_current",
+        action="store_true",
+        default=False,
+        help=_("Set colors of the current terminal from settings."),
+    )
+
+    parser.add_option(
+        "--rename-tab",
+        dest="rename_tab",
+        metavar="TITLE",
+        action="store",
+        default="",
+        help=_(
+            "Rename the specified tab by --tab-index. Reset to default if TITLE is "
             'a single dash "-".'
-        )
+        ),
     )
 
     parser.add_option(
-        '-r',
-        '--rename-current-tab',
-        dest='rename_current_tab',
-        metavar='TITLE',
-        action='store',
-        default='',
-        help=_('Rename the current tab. Reset to default if TITLE is a '
-               'single dash "-".')
+        "-r",
+        "--rename-current-tab",
+        dest="rename_current_tab",
+        metavar="TITLE",
+        action="store",
+        default="",
+        help=_("Rename the current tab. Reset to default if TITLE is a " 'single dash "-".'),
     )
 
     parser.add_option(
-        '-q',
-        '--quit',
-        dest='quit',
-        action='store_true',
+        "-q",
+        "--quit",
+        dest="quit",
+        action="store_true",
         default=False,
-        help=_('Says to Guake go away =(')
+        help=_("Says to Guake go away =("),
     )
 
     parser.add_option(
-        '-u',
-        '--no-startup-script',
-        dest='execute_startup_script',
-        action='store_false',
+        "-u",
+        "--no-startup-script",
+        dest="execute_startup_script",
+        action="store_false",
         default=True,
-        help=_('Do not execute the start up script')
+        help=_("Do not execute the start up script"),
     )
 
     parser.add_option(
-        '--save-preferences',
-        dest='save_preferences',
-        action='store',
+        "--save-preferences",
+        dest="save_preferences",
+        action="store",
         default=None,
-        help=_('Save Guake preferences to this filename')
+        help=_("Save Guake preferences to this filename"),
     )
 
     parser.add_option(
-        '--restore-preferences',
-        dest='restore_preferences',
-        action='store',
+        "--restore-preferences",
+        dest="restore_preferences",
+        action="store",
         default=None,
-        help=_('Restore Guake preferences from this file')
+        help=_("Restore Guake preferences from this file"),
     )
 
     parser.add_option(
-        '--support',
-        dest='support',
-        action='store_true',
+        "--support",
+        dest="support",
+        action="store_true",
         default=False,
-        help=_('Show support infomations')
+        help=_("Show support information"),
     )
 
     # checking mandatory dependencies
-    import gi
+
+    missing_deps = False
+    try:
+        import gi
+
+        gi.require_version("Gtk", "3.0")
+        gi.require_version("Gdk", "3.0")
+    except ValueError:
+        print("[ERROR] missing mandatory dependency: GtK 3.0")
+        missing_deps = True
 
     try:
-        gi.require_version('Gtk', '3.0')
-        gi.require_version('Gdk', '3.0')
+        gi.require_version("Vte", "2.91")  # vte-0.42
     except ValueError:
-        print("[ERROR] Unable to start Guake, missing mandatory dependency: GtK 3.0")
-        sys.exit(1)
+        print("[ERROR] missing mandatory dependency: Vte >= 0.42")
+        missing_deps = True
 
     try:
-        gi.require_version('Vte', '2.91')  # vte-0.42
+        gi.require_version("Keybinder", "3.0")
     except ValueError:
-        print("[ERROR] Unable to start Guake, missing mandatory dependency: Vte >= 0.42")
-        sys.exit(1)
+        print("[ERROR] missing mandatory dependency: Keybinder 3")
+        missing_deps = True
 
-    try:
-        gi.require_version('Keybinder', '3.0')
-    except ValueError:
-        print("[ERROR] Unable to start Guake, missing mandatory dependency: Keybinder 3")
+    if missing_deps:
+        print(
+            "[ERROR] missing at least one system dependencies. "
+            "You need to install additional packages for Guake to run"
+        )
+        print(
+            "[ERROR] On Debian/Ubuntu you need to install the following libraries:\n"
+            "    sudo apt-get install -y --no-install-recommends \\\n"
+            "        gir1.2-keybinder-3.0 \\\n"
+            "        gir1.2-notify-0.7 \\\n"
+            "        gir1.2-vte-2.91 \\\n"
+            "        gir1.2-wnck-3.0 \\\n"
+            "        libkeybinder-3.0-0 \\\n"
+            "        libutempter0 \\\n"
+            "        python3 \\\n"
+            "        python3-dbus \\\n"
+            "        python3-gi \\\n"
+            "        python3-pbr \\\n"
+            "        python3-pip"
+        )
         sys.exit(1)
 
     options = parser.parse_args()[0]
@@ -323,14 +414,15 @@ def main():
         from guake import guake_version
         from guake import vte_version
         from guake import vte_runtime_version
-        print('Guake Terminal: {}'.format(guake_version()))
-        print('VTE: {}'.format(vte_version()))
-        print('VTE runtime: {}'.format(vte_runtime_version()))
-        print('Gtk: {}'.format(gtk_version()))
+
+        print(f"Guake Terminal: {guake_version()}")
+        print(f"VTE: {vte_version()}")
+        print(f"VTE runtime: {vte_runtime_version()}")
+        print(f"Gtk: {gtk_version()}")
         sys.exit(0)
 
     if options.save_preferences and options.restore_preferences:
-        parser.error('options --save-preferences and --restore-preferences are mutually exclusive')
+        parser.error("options --save-preferences and --restore-preferences are mutually exclusive")
     if options.save_preferences:
         save_preferences(options.save_preferences)
         sys.exit(0)
@@ -366,11 +458,12 @@ def main():
         # gnome-terminal.
         # To avoid confusing applications running inside Guake, clean up COLORTERM at startup.
         if "COLORTERM" in os.environ:
-            del os.environ['COLORTERM']
+            del os.environ["COLORTERM"]
 
         log.info("Guake not running, starting it")
         # late loading of the Guake object, to speed up dbus comm
         from guake.guake_app import Guake
+
         instance = Guake()
         remote_object = DbusManager(instance)
         already_running = False
@@ -380,6 +473,9 @@ def main():
     if options.fullscreen:
         remote_object.fullscreen()
 
+    if options.unfullscreen:
+        remote_object.unfullscreen()
+
     if options.show:
         remote_object.show_from_remote()
 
@@ -400,17 +496,17 @@ def main():
         if 0 <= selected < tab_count:
             remote_object.select_tab(selected)
         else:
-            sys.stderr.write('invalid index: %d\n' % selected)
+            sys.stderr.write(f"invalid index: {selected}\n")
         only_show_hide = options.show
 
     if options.selected_tab:
         selected = remote_object.get_selected_tab()
-        sys.stdout.write('%d\n' % selected)
+        sys.stdout.write(f"{selected}\n")
         only_show_hide = options.show
 
     if options.selected_tablabel:
         selectedlabel = remote_object.get_selected_tablabel()
-        sys.stdout.write('%s\n' % selectedlabel)
+        sys.stdout.write(f"{selectedlabel}\n")
         only_show_hide = options.show
 
     if options.split_vertical:
@@ -421,6 +517,20 @@ def main():
         remote_object.h_split_current_terminal()
         only_show_hide = options.show
 
+    if options.selected_terminal:
+        selected = remote_object.get_selected_terminal()
+        sys.stdout.write(f"{selected}\n")
+        only_show_hide = options.show
+
+    if options.select_terminal:
+        selected = int(options.select_terminal)
+        term_count = int(remote_object.get_term_count())
+        if 0 <= selected < term_count:
+            remote_object.select_terminal(selected)
+        else:
+            sys.stderr.write(f"invalid index: {selected}\n")
+        only_show_hide = options.show
+
     if options.command:
         remote_object.execute_command(options.command)
         only_show_hide = options.show
@@ -440,10 +550,26 @@ def main():
         remote_object.set_fgcolor(options.fgcolor)
         only_show_hide = options.show
 
+    if options.bgcolor_current:
+        remote_object.set_bgcolor_current_terminal(options.bgcolor_current)
+        only_show_hide = options.show
+
+    if options.fgcolor_current:
+        remote_object.set_fgcolor_current_terminal(options.fgcolor_current)
+        only_show_hide = options.show
+
     if options.palette_name:
         remote_object.change_palette_name(options.palette_name)
         only_show_hide = options.show
 
+    if options.reset_colors:
+        remote_object.reset_colors()
+        only_show_hide = options.show
+
+    if options.reset_colors_current:
+        remote_object.reset_colors_current()
+        only_show_hide = options.show
+
     if options.rename_current_tab:
         remote_object.rename_current_tab(options.rename_current_tab)
         only_show_hide = options.show
@@ -469,13 +595,15 @@ def main():
             startup_script = instance.settings.general.get_string("startup-script")
             if startup_script:
                 log.info("Calling startup script: %s", startup_script)
-                pid = subprocess.Popen([startup_script],
-                                       shell=True,
-                                       stdin=None,
-                                       stdout=None,
-                                       stderr=None,
-                                       close_fds=True)
-                log.info("Startup script started with pid: %s", pid)
+                with subprocess.Popen(
+                    [startup_script],
+                    shell=True,
+                    stdin=None,
+                    stdout=None,
+                    stderr=None,
+                    close_fds=True,
+                ) as pid:
+                    log.info("Startup script started with pid: %s", pid)
                 # Please ensure this is the last line !!!!
     else:
         log.info("--no-startup-script argument defined, so don't execute the startup script")
@@ -491,10 +619,12 @@ def exec_main():
         # Load gi pretty late, to speed up as much as possible the parsing of the option for DBus
         # comm through command line
         import gi
-        gi.require_version('Gtk', '3.0')
+
+        gi.require_version("Gtk", "3.0")
         from gi.repository import Gtk
+
         Gtk.main()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     exec_main()
