@@ -10,7 +10,7 @@ from guake.about import AboutDialog
 
 @pytest.fixture
 def dialog(mocker):
-    mocker.patch('guake.simplegladeapp.Gtk.Widget.show_all')
+    mocker.patch("guake.simplegladeapp.Gtk.Widget.show_all")
     try:
         old_os_environ = os.environ
         os.environ["LANGUAGE"] = "en_US.UTF-8"
@@ -21,8 +21,8 @@ def dialog(mocker):
 
 
 def test_version_test(dialog):
-    assert dialog.get_widget('aboutdialog').get_version() == guake_version()
+    assert dialog.get_widget("aboutdialog").get_version() == guake_version()
 
 
 def test_title(dialog):
-    assert dialog.get_widget('aboutdialog').get_title() == 'About Guake'
+    assert dialog.get_widget("aboutdialog").get_title() == "About Guake"
