@@ -1,7 +1,6 @@
 import re
 
 from guake.globals import QUICK_OPEN_MATCHERS
-from mock import Mock
 from textwrap import dedent
 
 
@@ -16,13 +15,13 @@ def test_quick_open():
     )
 
     found = _execute_quick_open(chunk)
-    assert found == [('./test.py', '5')]
+    assert found == [("./test.py", "5")]
 
 
 def _execute_quick_open(chunk):
     found = []
 
-    for line in chunk.split('\n'):
+    for line in chunk.split("\n"):
         for _1, _2, r in QUICK_OPEN_MATCHERS:
             g = re.compile(r).match(line)
             if g:
